@@ -34,9 +34,9 @@ class MonitorController(MiddlewareInterface):
         self.monitor_cfg["mysql"]["ipaddress"] = self.handler.cfg["ipaddress"]
         self.monitor_cfg["elasticsearch"]["ipaddress"] = self.handler.cfg["ipaddress"]
         self.registry_hub = "{}:{}".format(self.monitor_cfg["monitor"]["harbor_ipaddress"],
-                                           self.monitor_cfg["monitor"]["harbor_http_port"])
+                                           self.monitor_cfg["monitor"]["nginx_harbor_proxy_port"])
         self.servers = result.servers.get()
-
+        
     def _generic_config(self):
         log.info("渲染 Monitor 配置文件")
         self.monitor_cfg["monitor"]["master"] = True
