@@ -4,7 +4,7 @@ from __future__ import unicode_literals
 from laipvt.sysutil.conf import YamlConfig
 from laipvt.sysutil.gvalue import PORT_MAP
 
-module_require_tfserver = ("ocr_standard", "captcha", "nlp")
+module_require_tfserver = ("ocr_standard", "captcha", "nlp", "ocr_seal_server")
 tfserver_name = {
     "ocr_standard": ["ocr-ctpn-tf-server", "ocr-text-recognition-tf-server",
                      "ocr-unet-table-tf-serving", "semantic-correct"],
