@@ -106,6 +106,34 @@ class Mage_test(object):
             {"secret_name": "通用多卡证识别-行驶证-高级版GPU", "app_name": "测试平台专用-行驶证-GPU"},
             {"secret_name": "通用多卡证识别-营业执照-高级版GPU", "app_name": "测试平台专用-营业执照-GPU"},
             {"secret_name": "通用多卡证识别-车辆登记证-高级版GPU", "app_name": "测试平台专用-车辆登记证GPU"},
+            {"secret_name": "印章识别-高级版", "app_name": "测试平台专用-印章识别-高级版"},
+            {"secret_name": "印章识别-标准版", "app_name": "测试平台专用-印章识别-标准版"},
+            {"secret_name": "通用文字识别-探智立方", "app_name": "测试平台专用-文字-探智立方"},
+            {"secret_name": "通通用表格识别-探智立方", "app_name": "测试平台专用-表格-探智立方"},
+            {"secret_name": "通用多票据识别-探智立方", "app_name": "测试平台-票据-探智立方GPU"},
+            {"secret_name": "通用卡证-身份证-探智立方", "app_name": "通用卡证-身份证-探智立方"},
+            {"secret_name": "自定义模板-探智立方", "app_name": "自定义模板-探智立方"},
+            {"secret_name": "红头文件-高级版", "app_name": "红头文件-高级版"},
+            {"secret_name": "招标公告-高级版", "app_name": "招标公告-高级版"},
+            {"secret_name": "简历-高级版", "app_name": "简历-高级版"},
+            {"secret_name": "简历-标准版", "app_name": "简历-标准版"},
+            {"secret_name": "红头文件-标准版", "app_name": "红头文件-标准版"},
+            {"secret_name": "招标公告-标准版", "app_name": "招标公告-标准版"},
+            {"secret_name": "简历-高级版CPU", "app_name": "简历-高级版CPU"},
+            {"secret_name": "简历-高级版GPU", "app_name": "简历-高级版GPU"},
+            {"secret_name": "简历-探智立方GPU", "app_name": "简历-探智立方GPU"},
+            {"secret_name": "红头文件-高级版CPU", "app_name": "红头文件-高级版CPU"},
+            {"secret_name": "红头文件-高级版GPU", "app_name": "红头文件-高级版GPU"},
+            {"secret_name": "红头文件-探智立方GPU", "app_name": "红头文件-探智立方GPU"},
+            {"secret_name": "招标公告-高级版CPU", "app_name": "招标公告-高级版CPU"},
+            {"secret_name": "招标公告-高级版GPU", "app_name": "招标公告-高级版GPU"},
+            {"secret_name": "招标公告-探智立方GPU", "app_name": "招标公告-探智立方GPU"},
+            {"secret_name": "合同比对-标准版", "app_name": "合同比对-标准版"},
+            {"secret_name": "合同比对-高级版", "app_name": "合同比对-高级版"},
+            {"secret_name": "合同比对-高级版-CPU", "app_name": "合同比对-高级版-CPU"},
+            {"secret_name": "合同比对-高级版-GPU", "app_name": "合同比对-高级版-GPU"},
+            {"secret_name": "合同比对-探智立方GPU", "app_name": "合同比对-探智立方GPU"},
+            {"secret_name": "通用卡证-营业执照-探智立方", "app_name": "通用卡证-营业执照-探智立方"}
         ]
         # Connect to the database
         with grpc.insecure_channel(self.grpc_url) as channel:
